@@ -111,12 +111,12 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
     }
 
     //if the representation didn't change, don't do anything
-    if (representationLayout.data() == layout) {
+    if (representationLayout == layout) {
         return;
     }
 
     if (representationLayout) {
-        QObject::disconnect(representationLayout.data(), 0, q, 0);
+        QObject::disconnect(representationLayout, 0, q, 0);
     }
 
     //Here we can't use the new connect syntax because we can't link against QtQuick layouts
@@ -156,82 +156,77 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
 void AppletQuickItemPrivate::propagateSizeHint(const QByteArray &layoutProperty)
 {
     if (ownLayout && representationLayout) {
-        ownLayout.data()->setProperty(layoutProperty, representationLayout.data()->property(layoutProperty));
+        ownLayout->setProperty(layoutProperty, representationLayout->property(layoutProperty));
     }
 }
 
-QObject *AppletQuickItemPrivate::createCompactRepresentationItem()
+QQuickItem *AppletQuickItemPrivate::createCompactRepresentationItem()
 {
     if (!compactRepresentation) {
         return 0;
     }
 
     if (compactRepresentationItem) {
-        return compactRepresentationItem.data();
+        return compactRepresentationItem;
     }
 
-    compactRepresentationItem = qmlObject->createObjectFromComponent(compactRepresentation.data(), QtQml::qmlContext(qmlObject->rootObject()));
+    compactRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(compactRepresentation, QtQml::qmlContext(qmlObject->rootObject())));
 
-    emit q->compactRepresentationItemChanged(compactRepresentationItem.data());
+    emit q->compactRepresentationItemChanged(compactRepresentationItem);
 
-    return compactRepresentationItem.data();
+    return compactRepresentationItem;
 }
 
-QObject *AppletQuickItemPrivate::createFullRepresentationItem()
+QQuickItem *AppletQuickItemPrivate::createFullRepresentationItem()
 {
     if (fullRepresentationItem) {
-        return fullRepresentationItem.data();
+        return fullRepresentationItem;
     }
 
-    if (fullRepresentation && fullRepresentation.data() != qmlObject->mainComponent()) {
-        fullRepresentationItem = qmlObject->createObjectFromComponent(fullRepresentation.data(), QtQml::qmlContext(qmlObject->rootObject()));
+    if (fullRepresentation && fullRepresentation != qmlObject->mainComponent()) {
+        fullRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(fullRepresentation, QtQml::qmlContext(qmlObject->rootObject())));
     } else {
         fullRepresentation = qmlObject->mainComponent();
-        fullRepresentationItem = qmlObject->rootObject();
-        emit q->fullRepresentationChanged(fullRepresentation.data());
+        fullRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->rootObject());
+        emit q->fullRepresentationChanged(fullRepresentation);
     }
 
     if (!fullRepresentationItem) {
         return 0;
     }
 
-    QQuickItem *graphicsObj = qobject_cast<QQuickItem *>(fullRepresentationItem.data());
+    emit q->fullRepresentationItemChanged(fullRepresentationItem);
 
-    QObject::connect(graphicsObj, &QQuickItem::widthChanged, [ = ]() {
-        fullRepresentationResizeTimer.start();
-    });
-    QObject::connect(graphicsObj, &QQuickItem::heightChanged, [ = ]() {
-        fullRepresentationResizeTimer.start();
-    });
-
-    emit q->fullRepresentationItemChanged(fullRepresentationItem.data());
-
-    return fullRepresentationItem.data();
+    return fullRepresentationItem;
 }
 
-QObject *AppletQuickItemPrivate::createCompactRepresentationExpanderItem()
+QQuickItem *AppletQuickItemPrivate::createCompactRepresentationExpanderItem()
 {
     if (!compactRepresentationExpander) {
         return 0;
     }
 
     if (compactRepresentationExpanderItem) {
-        return compactRepresentationExpanderItem.data();
+        return compactRepresentationExpanderItem;
     }
 
-    compactRepresentationExpanderItem = qmlObject->createObjectFromComponent(compactRepresentationExpander.data(), QtQml::qmlContext(qmlObject->rootObject()));
+    compactRepresentationExpanderItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(compactRepresentationExpander, QtQml::qmlContext(qmlObject->rootObject())));
 
     if (!compactRepresentationExpanderItem) {
         return 0;
     }
 
-    compactRepresentationExpanderItem.data()->setProperty("compactRepresentation", QVariant::fromValue(createCompactRepresentationItem()));
+    compactRepresentationExpanderItem->setProperty("compactRepresentation", QVariant::fromValue<QObject*>(createCompactRepresentationItem()));
 
-    return compactRepresentationExpanderItem.data();
+    return compactRepresentationExpanderItem;
 }
 
 void AppletQuickItemPrivate::compactRepresentationCheck()
 {
+    if (!qmlObject->mainComponent() || qmlObject->mainComponent()->status() != QQmlComponent::Ready) {
+        return;
+    }
+
     //ignore 0,0 sizes;
     if (q->width() <= 0 && q->height() <= 0) {
         return;
@@ -249,15 +244,15 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
         } else {
             //preferred representation set?
             if (preferredRepresentation) {
-                full = preferredRepresentation.data() == fullRepresentation.data();
+                full = preferredRepresentation == fullRepresentation;
                 //Otherwise, base on FormFactor
             } else {
                 full = (applet->formFactor() != Plasma::Types::Horizontal && applet->formFactor() != Plasma::Types::Vertical);
             }
         }
 
-        if ((full && fullRepresentationItem && fullRepresentationItem.data() == currentRepresentationItem.data()) ||
-                (!full && compactRepresentationItem && compactRepresentationItem.data() == currentRepresentationItem.data())
+        if ((full && fullRepresentationItem && fullRepresentationItem == currentRepresentationItem) ||
+                (!full && compactRepresentationItem && compactRepresentationItem == currentRepresentationItem)
            ) {
             return;
         }
@@ -265,14 +260,14 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
 
     //Expanded
     if (full) {
-        QQuickItem *item = qobject_cast<QQuickItem *>(createFullRepresentationItem());
+        QQuickItem *item = createFullRepresentationItem();
 
         if (item) {
             //unwire with the expander
             if (compactRepresentationExpanderItem) {
-                compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant());
-                compactRepresentationExpanderItem.data()->setProperty("compactRepresentation", QVariant());
-                compactRepresentationExpanderItem.data()->setProperty("visible", false);
+                compactRepresentationExpanderItem->setProperty("fullRepresentation", QVariant());
+                compactRepresentationExpanderItem->setProperty("compactRepresentation", QVariant());
+                compactRepresentationExpanderItem->setVisible(false);
             }
 
             item->setParentItem(q);
@@ -284,7 +279,7 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             }
 
             if (compactRepresentationItem) {
-                compactRepresentationItem.data()->setProperty("visible", false);
+                compactRepresentationItem->setVisible(false);
             }
 
             currentRepresentationItem = item;
@@ -295,8 +290,8 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
 
         //Icon
     } else {
-        QQuickItem *compactItem = qobject_cast<QQuickItem *>(createCompactRepresentationItem());
-        QQuickItem *compactExpanderItem = qobject_cast<QQuickItem *>(createCompactRepresentationExpanderItem());
+        QQuickItem *compactItem = createCompactRepresentationItem();
+        QQuickItem *compactExpanderItem = createCompactRepresentationExpanderItem();
 
         if (compactItem && compactExpanderItem) {
             //set the root item as the main visible item
@@ -311,12 +306,12 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             }
 
             if (fullRepresentationItem) {
-                fullRepresentationItem.data()->setProperty("parent", QVariant());
+                fullRepresentationItem->setProperty("parent", QVariant());
             }
 
-            compactExpanderItem->setProperty("compactRepresentation", QVariant::fromValue(compactItem));
+            compactExpanderItem->setProperty("compactRepresentation", QVariant::fromValue<QObject*>(compactItem));
             //The actual full representation will be connected when created
-            compactExpanderItem->setProperty("fullRepresentation", QVariant::fromValue(QVariant()));
+            compactExpanderItem->setProperty("fullRepresentation", QVariant());
 
             currentRepresentationItem = compactItem;
             connectLayoutAttached(compactItem);
@@ -367,6 +362,9 @@ void AppletQuickItemPrivate::fillHeightChanged()
     propagateSizeHint("fillHeight");
 }
 
+
+
+
 AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
     : QQuickItem(parent),
       d(new AppletQuickItemPrivate(applet, this))
@@ -382,21 +380,9 @@ AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
     d->compactRepresentationCheckTimer.setInterval(250);
     connect(&d->compactRepresentationCheckTimer, SIGNAL(timeout()),
             this, SLOT(compactRepresentationCheck()));
-    d->compactRepresentationCheckTimer.start();
-
-    d->fullRepresentationResizeTimer.setSingleShot(true);
-    d->fullRepresentationResizeTimer.setInterval(250);
-    connect(&d->fullRepresentationResizeTimer, &QTimer::timeout,
-    [ = ]() {
-        if (!d->applet->isContainment()) {
-            KConfigGroup cg = d->applet->config();
-            cg = KConfigGroup(&cg, "PopupApplet");
-            cg.writeEntry("DialogWidth", d->fullRepresentationItem.data()->property("width").toInt());
-            cg.writeEntry("DialogHeight", d->fullRepresentationItem.data()->property("height").toInt());
-        }
-    });
 
     d->qmlObject = new KDeclarative::QmlObject(this);
+    d->qmlObject->setTranslationDomain("plasma_applet_" + applet->pluginInfo().pluginName());
     d->qmlObject->setInitializationDelayed(true);
 
     // set the graphicObject dynamic property on applet
@@ -407,9 +393,9 @@ AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
 AppletQuickItem::~AppletQuickItem()
 {
     //Here the order is important
-    delete d->compactRepresentationItem.data();
-    delete d->fullRepresentationItem.data();
-    delete d->compactRepresentationExpanderItem.data();
+    delete d->compactRepresentationItem;
+    delete d->fullRepresentationItem;
+    delete d->compactRepresentationExpanderItem;
 
     AppletQuickItemPrivate::s_rootObjects.remove(d->qmlObject->engine());
 }
@@ -479,42 +465,45 @@ void AppletQuickItem::init()
 
     //initialize size, so an useless resize less
     QVariantHash initialProperties;
-    initialProperties["width"] = width();
-    initialProperties["height"] = height();
+    //initialize with our size only if valid
+    if (width() > 0 && height() > 0) {
+        initialProperties["width"] = width();
+        initialProperties["height"] = height();
+    }
     d->qmlObject->completeInitialization(initialProperties);
 
+    //otherwise, initialize our size to root object's size
+    if (d->qmlObject->rootObject() && (width() <= 0 || height() <= 0)) {
+        setWidth(d->qmlObject->rootObject()->property("width").value<qreal>());
+        setHeight(d->qmlObject->rootObject()->property("height").value<qreal>());
+    }
+
+
     //default fullrepresentation is our root main component, if none specified
     if (!d->fullRepresentation) {
         d->fullRepresentation = d->qmlObject->mainComponent();
-        d->fullRepresentationItem = d->qmlObject->rootObject();
+        d->fullRepresentationItem = qobject_cast<QQuickItem*>(d->qmlObject->rootObject());
 
-        if (d->qmlObject->rootObject()) {
-            QQuickItem *graphicsObj = qobject_cast<QQuickItem *>(d->fullRepresentationItem.data());
-            QObject::connect(graphicsObj, &QQuickItem::widthChanged, [ = ]() {
-                d->fullRepresentationResizeTimer.start();
-            });
-            QObject::connect(graphicsObj, &QQuickItem::heightChanged, [ = ]() {
-                d->fullRepresentationResizeTimer.start();
-            });
-        }
-        emit fullRepresentationChanged(d->fullRepresentation.data());
+        emit fullRepresentationChanged(d->fullRepresentation);
     }
 
-    //default d->compactRepresentation is a simple icon provided by the shell package
+    //default compactRepresentation is a simple icon provided by the shell package
     if (!d->compactRepresentation) {
         d->compactRepresentation = new QQmlComponent(engine, this);
-        d->compactRepresentation.data()->loadUrl(QUrl::fromLocalFile(d->coronaPackage.filePath("defaultcompactrepresentation")));
-        emit compactRepresentationChanged(d->compactRepresentation.data());
+        d->compactRepresentation->loadUrl(QUrl::fromLocalFile(d->coronaPackage.filePath("defaultcompactrepresentation")));
+        emit compactRepresentationChanged(d->compactRepresentation);
     }
 
-    //default d->compactRepresentationExpander is the popup in which fullRepresentation goes
+    //default compactRepresentationExpander is the popup in which fullRepresentation goes
     if (!d->compactRepresentationExpander) {
         d->compactRepresentationExpander = new QQmlComponent(engine, this);
-        d->compactRepresentationExpander.data()->loadUrl(QUrl::fromLocalFile(d->coronaPackage.filePath("compactapplet")));
+        d->compactRepresentationExpander->loadUrl(QUrl::fromLocalFile(d->coronaPackage.filePath("compactapplet")));
     }
 
+    d->compactRepresentationCheckTimer.start();
 }
 
+
 Plasma::Package AppletQuickItem::appletPackage() const
 {
     return d->appletPackage;
@@ -567,12 +556,12 @@ void AppletQuickItem::setSwitchHeight(int width)
 
 QQmlComponent *AppletQuickItem::compactRepresentation()
 {
-    return d->compactRepresentation.data();
+    return d->compactRepresentation;
 }
 
 void AppletQuickItem::setCompactRepresentation(QQmlComponent *component)
 {
-    if (d->compactRepresentation.data() == component) {
+    if (d->compactRepresentation == component) {
         return;
     }
 
@@ -582,12 +571,12 @@ void AppletQuickItem::setCompactRepresentation(QQmlComponent *component)
 
 QQmlComponent *AppletQuickItem::fullRepresentation()
 {
-    return d->fullRepresentation.data();
+    return d->fullRepresentation;
 }
 
 void AppletQuickItem::setFullRepresentation(QQmlComponent *component)
 {
-    if (d->fullRepresentation.data() == component) {
+    if (d->fullRepresentation == component) {
         return;
     }
 
@@ -597,12 +586,12 @@ void AppletQuickItem::setFullRepresentation(QQmlComponent *component)
 
 QQmlComponent *AppletQuickItem::preferredRepresentation()
 {
-    return d->preferredRepresentation.data();
+    return d->preferredRepresentation;
 }
 
 void AppletQuickItem::setPreferredRepresentation(QQmlComponent *component)
 {
-    if (d->preferredRepresentation.data() == component) {
+    if (d->preferredRepresentation == component) {
         return;
     }
 
@@ -631,23 +620,14 @@ void AppletQuickItem::setExpanded(bool expanded)
         d->createFullRepresentationItem();
         if (!d->applet->isContainment() &&
                 (!d->preferredRepresentation ||
-                 d->preferredRepresentation.data() != d->fullRepresentation.data())) {
+                 d->preferredRepresentation != d->fullRepresentation)) {
             d->createCompactRepresentationExpanderItem();
         }
 
-        KConfigGroup cg = d->applet->config();
-        cg = KConfigGroup(&cg, "PopupApplet");
-        const int width = cg.readEntry("DialogWidth", -1);
-        const int height = cg.readEntry("DialogHeight", -1);
-        if (width > 0  && height > 0) {
-            d->fullRepresentationItem.data()->setProperty("width", width);
-            d->fullRepresentationItem.data()->setProperty("height", height);
-        }
-
         if (d->compactRepresentationExpanderItem) {
-            d->compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(d->createFullRepresentationItem()));
+            d->compactRepresentationExpanderItem->setProperty("fullRepresentation", QVariant::fromValue<QObject*>(d->createFullRepresentationItem()));
         } else {
-            d->fullRepresentationItem.data()->setProperty("parent", QVariant::fromValue(this));
+            d->fullRepresentationItem->setProperty("parent", QVariant::fromValue<QObject*>(this));
         }
     }
 
@@ -662,14 +642,19 @@ KDeclarative::QmlObject *AppletQuickItem::qmlObject()
     return d->qmlObject;
 }
 
-QObject *AppletQuickItem::compactRepresentationItem()
+QQuickItem *AppletQuickItem::compactRepresentationItem()
 {
-    return d->compactRepresentationItem.data();
+    return d->compactRepresentationItem;
 }
 
-QObject *AppletQuickItem::fullRepresentationItem()
+QQuickItem *AppletQuickItem::fullRepresentationItem()
 {
-    return d->fullRepresentationItem.data();
+    return d->fullRepresentationItem;
+}
+
+QObject *AppletQuickItem::rootItem()
+{
+    return d->qmlObject->rootObject();
 }
 
 void AppletQuickItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
